"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthBasic = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_type_1 = require("./auth-type");
class AuthBasic {
    constructor(fnVerify) {
        this.fnVerify = fnVerify;
    }
    static init(fnVerify) {
        this.self = new AuthBasic(fnVerify);
    }
    static async updateAccessToken(accessToken, username, password) {
        const payload = await this.instance.fnVerify({ username, password, channel: accessToken.info.channel });
        accessToken.type = auth_type_1.AccessTokenType.Basic;
        accessToken.grant = true;
        accessToken.info.auth = payload;
        accessToken.info.channel = payload?.channel || accessToken.info.channel || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.PARAMETER_MISSING, 'Auth channel is missing');
        accessToken.info.requestedBy = payload?.userId || payload?.email || payload?.phone_number;
        accessToken.info.localeCode = payload?.localeCode || accessToken.info.localeCode || 'en_US';
        return accessToken;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'AuthBasic initialization is required');
    }
}
exports.AuthBasic = AuthBasic;
//# sourceMappingURL=auth-basic.js.map